@@ -13,7 +13,7 @@ import itertools
 import numpy as np
 from collections import namedtuple
 from collections.abc import Hashable
-from .misc import OrderedDict, cached_property, cache
+from .misc import OrderedDict, cached_property, cache, add_to_signature
 ppc = pp.pyparsing_common
 from .grammar import generate_grammar, separator as separator_grammar, \
                      delimitedList, line_end, optional_quote,\
@@ -168,8 +168,8 @@ class BaseType:
         Is an ommision of the value possible, e.g. the option is given as Flag (only by name of the option)
     default_value
         The value used if the value is ommitted
-    do_not_output_value
-        The value, with which the variable should not be outputed at all (e.g. False for a flag)
+    do_not_output_the_option
+        The value, for which the variable should not be outputed at all (e.g. False for a flag)
     """
     return False, None, None
 
@@ -252,14 +252,17 @@ class BaseType:
     access the items of the sequence using [] """
     pass
 
+  def __repr__(self):
+    return "<{}>".format(self.__class__.__name__)
+
 class Unsigned(BaseType):
   """ Unsigned integer (zero is possible) """
 
   _grammar = replace_whitechars(ppc.integer).setParseAction(lambda x:int(x[0]))
 
   def _validate(self, value, parse_check=False):
-    if not isinstance(value, int): return "Integer value required"
-    return value >= 0 or "Positive value required"
+    if not isinstance(value, int): return "An integer value required"
+    return value >= 0 or "A positive value required"
 
   def grammar_name(self):
     return '<+int>'
@@ -274,7 +277,7 @@ class Integer(BaseType):
   _grammar = replace_whitechars(ppc.signed_integer).setParseAction(lambda x:int(x[0]))
 
   def _validate(self, value, parse_check=False):
-    return isinstance(value, (int, np.int64) ) or f'Integer value required ({value.__class__} was given)'
+    return isinstance(value, (int, np.int64) ) or f'An integer value required, ({value.__class__} was given)'
 
   def grammar_name(self):
     return '<int>'
@@ -288,7 +291,7 @@ class Bool(BaseType):
   _grammar = (pp.CaselessKeyword('T') | pp.CaselessKeyword('F')).setParseAction( lambda x: x[0] == 'T' )
 
   def _validate(self, value, parse_check=False):
-    return isinstance(value, bool) or "Bool value rquired"
+    return isinstance(value, bool) or "A bool value rquired"
 
   def grammar_name(self):
     return '<T|F>'
@@ -306,7 +309,7 @@ class Real(BaseType):
   _grammar = replace_whitechars(ppc.fnumber).setParseAction(lambda x: float(x[0]))
 
   def _validate(self, value, parse_check=False):
-    return isinstance(value, float) or "Float value required"
+    return isinstance(value, float) or "A float value required"
 
   def grammar_name(self):
     return '<float>'
@@ -321,7 +324,7 @@ class Date(BaseType):
   _grammar = pp.Regex(r'(?P<d>\d{2}).(?P<m>\d{2}).(?P<y>\d{4})').setParseAction(lambda x: datetime.date(int(x['y']), int(x['m']), int(x['d'])))
 
   def _validate(self, value, parse_check=False):
-    return isinstance(value, datetime.date) or "Date (datetime.date) value required"
+    return isinstance(value, datetime.date) or "A date (datetime.date) value required"
 
   def grammar_name(self):
     return '<dd.mm.yyyy>'
@@ -357,7 +360,7 @@ class BaseRealWithUnits(BaseType):
     return self._grammar_units(self.units)
 
   def _validate(self, value, parse_check=False):
-    return isinstance(value, float) or "Float value required"
+    return isinstance(value, float) or "A float value required"
 
   def grammar_name(self):
     return '<float>[{}]'.format("|".join(('' if i is None else i for i in self.units)))
@@ -387,7 +390,7 @@ class BaseString(BaseType):
   """ Base type for string grammar types """
 
   def _validate(self, value, parse_check=False):
-    if not isinstance(value, str): return "String value required"
+    if not isinstance(value, str): return "A string value required"
     if not parse_check:
       try:
         self._grammar.parseString(value, True)
@@ -486,7 +489,7 @@ def normalize_type(type):
 
     doctest:
     >>> normalize_type(np.int64)
-    int
+    <class 'int'>
     """
     return normalize_type_map.get(type, type)
 
@@ -560,6 +563,28 @@ class Array(BaseType):
                length=None, max_length=None, min_length=None,
                as_list=False,
                **kwargs):
+    """
+    Parameters
+    ----------
+    type
+      The grammar type of the values in the list (it can be given by a python type)
+
+    default_value
+      The default value for the list
+
+    length
+      If it is set, the list have to have just this length (it sets ``min_`` and ``max_length`` to the ``length``)
+
+    min_length
+      The minimal allowed length of the list.
+
+    max_length
+      The maximal allowed length of the list.
+
+    as_list
+      Type of the value array. True means List, False means np.ndarray, or custom type (e.g. tuple)
+      can be provided. However, the value can be set using tuple or list anyway.
+    """
     if isinstance(type, (list, np.ndarray)):
         if default_value is not None:
            raise ValueException("It is not possible for an Array to provide default_value both in 'default_value' and in 'type' argument")
@@ -609,7 +634,7 @@ class Array(BaseType):
     else:
        cls = np.ndarray
     if not isinstance(value, cls):
-       return f'{cls} type required, {value.__class__} is given'
+       return f'A value of the {cls} type is required, a {value.__class__} is given'
 
     for i,v in enumerate(value):
         try:
@@ -618,7 +643,7 @@ class Array(BaseType):
            raise ValueError("Value {} in the set is incorrect: {}".format(i, str(e))) from e
     if self.min_length is not None and len(value) < self.min_length:
        return f"The array should be at least {self.min_length} items long, it has {len(value)} items"
-    if self.max_length is not None and len(value) > self.min_length:
+    if self.max_length is not None and len(value) > self.max_length:
        return f"The array can not have more than {self.max_length} items, it has {len(value)} items"
     return True
 
@@ -626,7 +651,8 @@ class Array(BaseType):
     if self.as_list:
        if callable(self.as_list):
           return value if isinstance(value, self.as_list) else self.as_list(value)
-       return list(value) if isinstance(value, tuple) else value
+       else:
+          return list(value) if isinstance(value, tuple) else value
     if not isinstance(value, np.ndarray):
        if self.type.numpy_type == object:
           #https://stackoverflow.com/questions/60939396/forcing-a-creation-of-1d-numpy-array-from-a-list-array-of-possibly-iterable-obje
@@ -664,17 +690,19 @@ type_from_set_map = OrderedDict([
 Only canonical types are expected, see :meth:`ase2sprkkr.common.grammar_types.normalize_type`
 """
 
+recognized_set_types = ( list, tuple, np.ndarray )
+
 def type_from_value(value):
   """ Gues the grammar type from a python value.
 
   ..doctest::
   >>> type_from_value(2)
-  Integer
+  <Integer>
 
   >>> type_from_value(2.0)
-  Real
+  <Real>
   """
-  if isinstance(value, (list, np.ndarray)):
+  if isinstance(value, recognized_set_types):
      return type_from_set_map[normalize_type(value[0].__class__)] if len(value) else Integer.I
   if isinstance(value, str):
      try:
@@ -713,25 +741,44 @@ class BaseMixed(BaseType):
   string_type = None
   """ Type of string grammar_type to be used.  To be redefined in the descendants. """
 
-  @classmethod
-  def _grammar(cls, param_name=False):
-    return pp.MatchFirst((
-      i.grammar(param_name) for i in cls.types
-    ))
+  def _grammar(self, param_name=False):
+      return pp.MatchFirst((
+        i.grammar(param_name) for i in self.types
+      ))
 
   def get_type(self, value):
       """ Return the type of the value """
       return self.string_type if isinstance(value, str) else type_from_value(value)
 
   def _validate(self, value, parse_check=False):
-    type = self.get_type(value)
-    if type is value:
-       return 'Can not determine the type of value {}'.format(value)
-    return type.validate(value, parse_check)
+      type = self.get_type(value)
+      if type is value:
+         return 'Can not determine the type of value {}'.format(value)
+      return type.validate(value, parse_check)
 
   def grammar_name(self):
-    return '<mixed>'
+      return '<mixed>'
 
+  def convert(self, value):
+      return self.get_type(value).convert(value)
+
+class Range(BaseMixed):
+  """ A range type - it accepts either one value or range of two values of a given type."""
+
+  @add_to_signature(BaseMixed.__init__, prepend=True)
+  def __init__(self, type, *args, **kwargs):
+      self._type = type_from_type(type)
+      super().__init__(*args, **kwargs)
+
+  @cached_property
+  def types(self):
+      return [
+          self._type,
+          SetOf(self._type, min_length=2, max_length=2)
+      ]
+
+  def get_type(self, value):
+      return self.types[1 if isinstance(value, recognized_set_types) else 0]
 
 class Mixed(BaseMixed):
   """ A variant value to be used in input files (in unknown - custom - options) """
