@@ -4,10 +4,12 @@ import functools
 import inspect
 import heapq
 import copy
+import itertools
 import asyncio
 import numpy as np
 _x = object()
 from collections import OrderedDict as _OrderedDict
+from typing import Set
 
 try:
   from numba import njit
@@ -43,43 +45,116 @@ if hasattr(functools,'cache'):
 else:
    cache = functools.lru_cache(maxsize=None)
 
-def add_to_signature(func, add=set()):
+def add_to_signature(func, prepend=False, self_name='self'):
   """
   Add the arguments in the <func> function to the list of arguments
   of the resulting function (as keyword_only arguments)
   The modified function has to have its arguments defined as
   in the following example:
 
-
   .. code-block::
 
       def parent(.....):
           ....
 
       @add_to_signature(parent)
-      def child(*args, new_param, **kwargs):
+      def child(new_param, *args, **kwargs):
           print(f'New param is {new_param})
           parent(*args, **kwargs)
+
+
+  Parameters
+  ----------
+  func
+    A function, whose parameters will be added to the resulting function signature.
+
+  prepend
+    If true, the new positional arguments will be the first.
+    If false, they will be after the parents positional arguments.
+    The same-named arguments just alter the properties of the "old"
+    arguments, retaining their position.
+
+  self_name
+    Name of the self-parameter (for object method), that should be the first, even
+    if ``prepend`` is True.
+    Default self, set to None if you do not want special handling of self parameter
+    (i.e. if your function has the first argument named *self* and it is not a method).
+
   """
 
   signature = inspect.signature(func)
   pars = list( signature.parameters.values())
   P = inspect.Parameter
-  names = set((i.name for i in pars))
+
+  arg_ar = arg_kw = None
+  for i in pars:
+      if i.kind == P.VAR_KEYWORD:
+         arg_kw = i.name
+      elif i.kind == P.VAR_POSITIONAL:
+         arg_ar = i.name
 
   def modify(mod_func):
-      mod_sig = inspect.signature(mod_func)
-      pars2 = mod_sig.parameters.values()
-      forbidden = set((P.VAR_KEYWORD, P.VAR_POSITIONAL)) - add
-      if forbidden:
-         pars2 = (i for i in pars2 if i.kind not in forbidden and i.name not in names)
-      result = heapq.merge(pars, pars2, key = lambda x: x.kind)
+      new_sig = inspect.signature(mod_func)
+      new_pars = new_sig.parameters.values()
+
+      #remove args/kwargs from the childs argument
+      new_pars = { i.name:i for i in new_pars if i.kind != P.VAR_KEYWORD and i.kind != P.VAR_POSITIONAL }
+
+      used = set()
+      def use(i):
+          nonlocal used
+          used.add(i.name)
+          return i
+
+      old_pars = [ use(new_pars[i.name]) if i.name in new_pars else i for i in pars ]
+      add_pars = [ i for i in new_pars.values() if i.name not in used ]
+
+      #the easy and fast way - only keyword arguments are present, the function can be called as is,
+      #just make its signature pretty
+      for i in add_pars:
+        if i.kind != P.KEYWORD_ONLY:
+           break
+      else:
+        result = list(heapq.merge(old_pars, add_pars, key = lambda x: x.kind))
+        result = new_sig.replace(parameters = result)
+        mod_func.__signature__ = result
+        return mod_func
+
+      #the hard way, the arguments have to be rearranged
+      if prepend:
+         if old_pars and old_pars[0].name == self_name:
+            self = old_pars[0]
+            del old_pars[0]
+         else:
+            self = None
+         result = heapq.merge(add_pars, old_pars, key = lambda x: x.kind)
+         if self:
+            result = itertools.chain((self,), result)
+      else:
+         result = heapq.merge(old_pars, add_pars, key = lambda x: x.kind)
+         self = None
+
+      result = list(result)
+      result=new_sig.replace(parameters = result)
 
       @functools.wraps(mod_func)
       def wrapper(*args, **kwargs):
-          return mod_func(*args, **kwargs)
-      wrapper.__signature__ = mod_sig.replace(parameters = list(result))
+          ba=result.bind(*args, **kwargs)
+          ba.apply_defaults()
+          nargs = []
+          nkwargs = {}
+          for k,v in ba.arguments.items():
+              if k==arg_kw:
+                 nkwargs.update(v)
+              elif k==arg_ar:
+                 nargs.extend(v)
+              elif k in new_pars and new_pars[k].kind != P.KEYWORD_ONLY:
+                 nargs.append(v)
+              else:
+                 nkwargs[k]=v
+          return mod_func(*nargs, **nkwargs)
 
+      wrapper.__signature__ = result
       return wrapper
 
   return modify
